module.exports = defineTest({
	description: 'properly extract return values from function bodies'
});
